@@ -1,16 +1,16 @@
 /****************************************************************************
 **
-** Copyright (c) 2008-2012 C.B. Barber. All rights reserved.
-** $Id: //main/2011/qhull/src/libqhullcpp/QhullStat.cpp#3 $$Change: 1464 $
-** $DateTime: 2012/01/25 22:58:41 $$Author: bbarber $
+** Copyright (c) 2008-2015 C.B. Barber. All rights reserved.
+** $Id: //main/2015/qhull/src/libqhullcpp/QhullStat.cpp#3 $$Change: 2066 $
+** $DateTime: 2016/01/18 19:29:17 $$Author: bbarber $
 **
 ****************************************************************************/
 
 #//! QhullStat -- Qhull's global data structure, statT, as a C++ class
 
+#include "libqhullcpp/QhullStat.h"
 
-#include "QhullError.h"
-#include "QhullStat.h"
+#include "libqhullcpp/QhullError.h"
 
 #include <sstream>
 #include <iostream>
@@ -25,7 +25,7 @@ using std::ostream;
 
 namespace orgQhull {
 
-#//Constructor, destructor, etc.
+#//!\name Constructor, destructor, etc.
 
 //! If qh_QHpointer==0, invoke with placement new on qh_stat;
 QhullStat::
